==> 2.0.6.tar.gz: lib/src/models/video_feed_configuration.dart <==
import 'android_font_info.dart';
import 'ios_font_info.dart';

class VideoFeedConfiguration {
  /// The background color of video feed.
  String? backgroundColor;

  /// The corner radius of video feed.
  double? cornerRadius;

  /// The configuration of video feed title.
  VideoFeedTitleConfiguration? title;

  /// The title position of video feed.
  VideoFeedTitlePosition? titlePosition;

  /// The configuration of video feed play icon.
  VideoFeedPlayIconConfiguration? playIcon;

  /// Indicates if the video feed shows ad badge.
  bool? showAdBadge;

  /// The aspect ratio(width / height) for video feed item. Only supported on iOS.
  double? aspectRatio;

  /// The content padding for video feed. Only supported on iOS.
  VideoFeedContentPadding? contentPadding;

  /// The item spacing for video feed.
  double? itemSpacing;

  /// Specifies if autoplay is enabled.
  bool? enableAutoplay;

  /// The number of feed items to be displayed per row.
  /// The property only takes effect when video feed mode is grid.
  /// The property value needs to be greater than 0.
  int? gridColumns;

  VideoFeedConfiguration({
    this.backgroundColor,
    this.cornerRadius,
    this.title,
    this.titlePosition,
    this.playIcon,
    this.showAdBadge,
    this.aspectRatio,
    this.contentPadding,
    this.itemSpacing,
    this.enableAutoplay,
    this.gridColumns,
  });

  @override
  bool operator ==(Object other) {
    if (identical(this, other)) {
      return true;
    }

    if (other is VideoFeedConfiguration) {
      return backgroundColor == other.backgroundColor &&
          cornerRadius == other.cornerRadius &&
          title == other.title &&
          titlePosition == other.titlePosition &&
          playIcon == other.playIcon &&
          showAdBadge == other.showAdBadge &&
          aspectRatio == other.aspectRatio &&
          contentPadding == other.contentPadding &&
          itemSpacing == other.itemSpacing &&
          enableAutoplay == other.enableAutoplay &&
          gridColumns == other.gridColumns;
    }

    return false;
  }

  @override
  int get hashCode =>
      backgroundColor.hashCode ^
      cornerRadius.hashCode ^
      title.hashCode ^
      titlePosition.hashCode ^
      playIcon.hashCode ^
      showAdBadge.hashCode ^
      aspectRatio.hashCode ^
      contentPadding.hashCode ^
      itemSpacing.hashCode ^
      enableAutoplay.hashCode ^
      gridColumns.hashCode;

  VideoFeedConfiguration deepCopy() => VideoFeedConfiguration(
        backgroundColor: backgroundColor,
        cornerRadius: cornerRadius,
        title: title?.deepCopy(),
        titlePosition: titlePosition,
        playIcon: playIcon?.deepCopy(),
        showAdBadge: showAdBadge,
        aspectRatio: aspectRatio,
        contentPadding: contentPadding?.deepCopy(),
        itemSpacing: itemSpacing,
        enableAutoplay: enableAutoplay,
        gridColumns: gridColumns,
      );
}

class VideoFeedPlayIconConfiguration {
  /// Specifies if the play icon is hidden.
  bool? hidden;

  /// The width of play icon.
  double? iconWidth;

  VideoFeedPlayIconConfiguration({
    this.hidden,
    this.iconWidth,
  });

  @override
  bool operator ==(Object other) {
    if (identical(this, other)) {
      return true;
    }

    if (other is VideoFeedPlayIconConfiguration) {
      return hidden == other.hidden && iconWidth == other.iconWidth;
    }

    return false;
  }

  @override
  int get hashCode => hidden.hashCode ^ iconWidth.hashCode;

  VideoFeedPlayIconConfiguration deepCopy() => VideoFeedPlayIconConfiguration(
        hidden: hidden,
        iconWidth: iconWidth,
      );
}

class VideoFeedTitleConfiguration {
  /// Specifies if the video feed title is hidden.
  bool? hidden;

  /// The text color of video feed title.
  String? textColor;

  /// The font size of video feed title.
  double? fontSize;

  /// Specifies the number of allowed lines for the label.
  /// Only supported on iOS.
  int? numberOfLines;

  /// The iOS font info of video feed title.
  /// The property is ignored when fontSize is not set.
  /// Only supported on iOS.
  IOSFontInfo? iOSFontInfo;

  /// The Android font info of "VideoFeedTitle".
  /// The property is ignored when fontSize is not set.
  /// Only supported on Android.
  AndroidFontInfo? androidFontInfo;

  /// The background drawable of video feed title.
  /// Only supported on Android.
  GradientDrawable? gradientDrawable;

  VideoFeedTitleConfiguration({
    this.hidden,
    this.textColor,
    this.fontSize,
    this.numberOfLines,
    this.iOSFontInfo,
    this.androidFontInfo,
    this.gradientDrawable,
  });

  @override
  bool operator ==(Object other) {
    if (identical(this, other)) {
      return true;
    }

    if (other is VideoFeedTitleConfiguration) {
      return hidden == other.hidden &&
          textColor == other.textColor &&
          fontSize == other.fontSize &&
          numberOfLines == other.numberOfLines &&
          iOSFontInfo == other.iOSFontInfo &&
          androidFontInfo == androidFontInfo &&
          gradientDrawable == other.gradientDrawable;
    }

    return false;
  }

  @override
  int get hashCode =>
      hidden.hashCode ^
      textColor.hashCode ^
      fontSize.hashCode ^
      numberOfLines.hashCode ^
      iOSFontInfo.hashCode ^
      androidFontInfo.hashCode ^
      gradientDrawable.hashCode;

  VideoFeedTitleConfiguration deepCopy() => VideoFeedTitleConfiguration(
        hidden: hidden,
        textColor: textColor,
        fontSize: fontSize,
        numberOfLines: numberOfLines,
        iOSFontInfo: iOSFontInfo?.deepCopy(),
        androidFontInfo: androidFontInfo?.deepCopy(),
        gradientDrawable: gradientDrawable?.deepCopy(),
      );
}

enum GradientDrawableOrientation {
  topBottom("TOP_BOTTOM"),
  trBl("TR_BL"),
  rightLeft("RIGHT_LEFT"),
  brTl("BR_TL"),
  bottomTop("BOTTOM_TOP"),
  blTr("BL_TR"),
  leftRight("LEFT_RIGHT"),
  tlBr("TL_BR");

  final String rawName;
  const GradientDrawableOrientation(this.rawName);
}

class GradientDrawable {
  GradientDrawableOrientation? orientation;
  List<String>? colors;
  GradientDrawable({
    this.orientation,
    this.colors,
  });

  @override
  bool operator ==(Object other) {
    if (identical(this, other)) {
      return true;
    }

    if (other is GradientDrawable) {
      return orientation == other.orientation && colors == other.colors;
    }

    return false;
  }

  @override
  int get hashCode => orientation.hashCode ^ colors.hashCode;

  GradientDrawable deepCopy() => GradientDrawable(
        orientation: orientation,
        colors: colors,
      );
}

enum VideoFeedTitlePosition {
  stacked,
  nested,
}

class VideoFeedContentPadding {
  double? top;
  double? right;
  double? bottom;
  double? left;

  VideoFeedContentPadding({
    this.top,
    this.right,
    this.bottom,
    this.left,
  });

  @override
  bool operator ==(Object other) {
    if (identical(this, other)) {
      return true;
    }

    if (other is VideoFeedContentPadding) {
      return top == other.top &&
          right == other.right &&
          bottom == other.bottom &&
          left == other.left;
    }

    return false;
  }

  @override
  int get hashCode =>
      top.hashCode ^ right.hashCode ^ bottom.hashCode ^ left.hashCode;

  VideoFeedContentPadding deepCopy() => VideoFeedContentPadding(
        top: top,
        right: right,
        bottom: bottom,
        left: left,
      );
}

==> 2.4.6.tar.gz: lib/src/models/video_feed_configuration.dart <==
import 'android_font_info.dart';
import 'ios_font_info.dart';

class VideoFeedConfiguration {
  /// The background color of video feed.
  /// If you don't set this property, the background will be transparent.
  String? backgroundColor;

  /// The corner radius of video feed.
  /// Defaults to 10 on iOS. Defaults to 0 on Android.
  double? cornerRadius;

  /// The configuration of video feed title.
  VideoFeedTitleConfiguration? title;

  /// The title position of video feed.
  /// Defaults to nested.
  VideoFeedTitlePosition? titlePosition;

  /// The padding of video feed title.
  /// Defaults to { top: 8, right: 8, bottom: 8, left: 8 }.
  /// Only supported on iOS.
  VideoFeedPadding? titlePadding;

  /// The configuration of video feed play icon.
  VideoFeedPlayIconConfiguration? playIcon;

  /// Indicates if the video feed shows ad badge.
  /// Defaults to false.
  bool? showAdBadge;

  /// The aspect ratio(width / height) for video feed item.
  /// Defaults to 4 / 6.
  /// Only supported on iOS.
  double? aspectRatio;

  /// The content padding for video feed.
  /// Defaults to { top: 10, right: 10, bottom: 10, left: 10 }.
  /// Only supported on iOS.
  VideoFeedPadding? contentPadding;

  /// The item spacing for video feed.
  /// If you don't set this property, the item spacing will be 10 on iOS and 4px on Android.
  double? itemSpacing;

  /// Specifies if autoplay is enabled.
  /// Defaults to false.
  bool? enableAutoplay;

  /// The number of feed items to be displayed per row.
  /// The property only takes effect when video feed mode is grid.
  /// The property value needs to be greater than 0.
  /// Defaults to 2.
  int? gridColumns;

  VideoFeedConfiguration({
    this.backgroundColor,
    this.cornerRadius,
    this.title,
    this.titlePosition,
    this.titlePadding,
    this.playIcon,
    this.showAdBadge,
    this.aspectRatio,
    this.contentPadding,
    this.itemSpacing,
    this.enableAutoplay,
    this.gridColumns,
  });

  @override
  bool operator ==(Object other) {
    if (identical(this, other)) {
      return true;
    }

    if (other is VideoFeedConfiguration) {
      return backgroundColor == other.backgroundColor &&
          cornerRadius == other.cornerRadius &&
          title == other.title &&
          titlePosition == other.titlePosition &&
          titlePadding == other.titlePadding &&
          playIcon == other.playIcon &&
          showAdBadge == other.showAdBadge &&
          aspectRatio == other.aspectRatio &&
          contentPadding == other.contentPadding &&
          itemSpacing == other.itemSpacing &&
          enableAutoplay == other.enableAutoplay &&
          gridColumns == other.gridColumns;
    }

    return false;
  }

  @override
  int get hashCode =>
      backgroundColor.hashCode ^
      cornerRadius.hashCode ^
      title.hashCode ^
      titlePosition.hashCode ^
      titlePadding.hashCode ^
      playIcon.hashCode ^
      showAdBadge.hashCode ^
      aspectRatio.hashCode ^
      contentPadding.hashCode ^
      itemSpacing.hashCode ^
      enableAutoplay.hashCode ^
      gridColumns.hashCode;

  VideoFeedConfiguration deepCopy() => VideoFeedConfiguration(
        backgroundColor: backgroundColor,
        cornerRadius: cornerRadius,
        title: title?.deepCopy(),
        titlePosition: titlePosition,
        titlePadding: titlePadding?.deepCopy(),
        playIcon: playIcon?.deepCopy(),
        showAdBadge: showAdBadge,
        aspectRatio: aspectRatio,
        contentPadding: contentPadding?.deepCopy(),
        itemSpacing: itemSpacing,
        enableAutoplay: enableAutoplay,
        gridColumns: gridColumns,
      );
}

class VideoFeedPlayIconConfiguration {
  /// Specifies if the play icon is hidden.
  /// Defaults to false.
  bool? hidden;

  /// The width of play icon.
  /// If you don't set this property, the icon width will be 40 on iOS and 36dp on Android.
  double? iconWidth;

  VideoFeedPlayIconConfiguration({
    this.hidden,
    this.iconWidth,
  });

  @override
  bool operator ==(Object other) {
    if (identical(this, other)) {
      return true;
    }

    if (other is VideoFeedPlayIconConfiguration) {
      return hidden == other.hidden && iconWidth == other.iconWidth;
    }

    return false;
  }

  @override
  int get hashCode => hidden.hashCode ^ iconWidth.hashCode;

  VideoFeedPlayIconConfiguration deepCopy() => VideoFeedPlayIconConfiguration(
        hidden: hidden,
        iconWidth: iconWidth,
      );
}

class VideoFeedTitleConfiguration {
  /// Specifies if the video feed title is hidden.
  /// Defaults to false.
  bool? hidden;

  /// The text color of video feed title.
  ///  If you don't set this property, the text color will be white with alpha is 0.98 on iOS and #ffffff on Android.
  String? textColor;

  /// The font size of video feed title.
  /// If you don't set this property, the font size will be 12 on iOS and 14sp on Android.
  double? fontSize;

  /// Specifies the number of allowed lines for the label.
  /// Defaults to 2.
  /// Only supported on iOS.
  int? numberOfLines;

  /// The iOS font info of video feed title.
  /// The property is ignored when fontSize is not set.
  /// Only supported on iOS.
  IOSFontInfo? iOSFontInfo;

  /// The Android font info of "VideoFeedTitle".
  /// The property is ignored when fontSize is not set.
  /// Only supported on Android.
  AndroidFontInfo? androidFontInfo;

  /// The background drawable of video feed title.
  /// Only supported on Android.
  GradientDrawable? gradientDrawable;

  VideoFeedTitleConfiguration({
    this.hidden,
    this.textColor,
    this.fontSize,
    this.numberOfLines,
    this.iOSFontInfo,
    this.androidFontInfo,
    this.gradientDrawable,
  });

  @override
  bool operator ==(Object other) {
    if (identical(this, other)) {
      return true;
    }

    if (other is VideoFeedTitleConfiguration) {
      return hidden == other.hidden &&
          textColor == other.textColor &&
          fontSize == other.fontSize &&
          numberOfLines == other.numberOfLines &&
          iOSFontInfo == other.iOSFontInfo &&
          androidFontInfo == androidFontInfo &&
          gradientDrawable == other.gradientDrawable;
    }

    return false;
  }

  @override
  int get hashCode =>
      hidden.hashCode ^
      textColor.hashCode ^
      fontSize.hashCode ^
      numberOfLines.hashCode ^
      iOSFontInfo.hashCode ^
      androidFontInfo.hashCode ^
      gradientDrawable.hashCode;

  VideoFeedTitleConfiguration deepCopy() => VideoFeedTitleConfiguration(
        hidden: hidden,
        textColor: textColor,
        fontSize: fontSize,
        numberOfLines: numberOfLines,
        iOSFontInfo: iOSFontInfo?.deepCopy(),
        androidFontInfo: androidFontInfo?.deepCopy(),
        gradientDrawable: gradientDrawable?.deepCopy(),
      );
}

enum GradientDrawableOrientation {
  topBottom("TOP_BOTTOM"),
  trBl("TR_BL"),
  rightLeft("RIGHT_LEFT"),
  brTl("BR_TL"),
  bottomTop("BOTTOM_TOP"),
  blTr("BL_TR"),
  leftRight("LEFT_RIGHT"),
  tlBr("TL_BR");

  final String rawName;
  const GradientDrawableOrientation(this.rawName);
}

class GradientDrawable {
  GradientDrawableOrientation? orientation;
  List<String>? colors;
  GradientDrawable({
    this.orientation,
    this.colors,
  });

  @override
  bool operator ==(Object other) {
    if (identical(this, other)) {
      return true;
    }

    if (other is GradientDrawable) {
      return orientation == other.orientation && colors == other.colors;
    }

    return false;
  }

  @override
  int get hashCode => orientation.hashCode ^ colors.hashCode;

  GradientDrawable deepCopy() => GradientDrawable(
        orientation: orientation,
        colors: colors,
      );
}

enum VideoFeedTitlePosition {
  stacked,
  nested,
}

class VideoFeedPadding {
  double? top;
  double? right;
  double? bottom;
  double? left;

  VideoFeedPadding({
    this.top,
    this.right,
    this.bottom,
    this.left,
  });

  @override
  bool operator ==(Object other) {
    if (identical(this, other)) {
      return true;
    }

    if (other is VideoFeedPadding) {
      return top == other.top &&
          right == other.right &&
          bottom == other.bottom &&
          left == other.left;
    }

    return false;
  }

  @override
  int get hashCode =>
      top.hashCode ^ right.hashCode ^ bottom.hashCode ^ left.hashCode;

  VideoFeedPadding deepCopy() => VideoFeedPadding(
        top: top,
        right: right,
        bottom: bottom,
        left: left,
      );
}
